@@ -1,8 +1,8 @@
 /*
    +----------------------------------------------------------------------+
-   | PHP Version 5                                                        |
+   | PHP Version 7                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2016 The PHP Group                                |
+   | Copyright (c) 1997-2017 The PHP Group                                |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -63,6 +63,7 @@
  * Also works sensibly for win32 */
 BEGIN_EXTERN_C()
 PHPAPI char *php_socket_strerror(long err, char *buf, size_t bufsize);
+PHPAPI zend_string *php_socket_error_str(long err);
 END_EXTERN_C()
 
 #ifdef HAVE_NETINET_IN_H
@@ -73,6 +74,10 @@ END_EXTERN_C()
 #include <sys/socket.h>
 #endif
 
+#ifdef HAVE_GETHOSTBYNAME_R
+#include <netdb.h>
+#endif
+
 /* These are here, rather than with the win32 counterparts above,
  * since <sys/socket.h> defines them. */
 #ifndef SHUT_RD
@@ -105,11 +110,22 @@ typedef int php_socket_t;
 # define SOCK_RECV_ERR -1
 #endif
 
+#define STREAM_SOCKOP_NONE                (1 << 0)
+#define STREAM_SOCKOP_SO_REUSEPORT        (1 << 1)
+#define STREAM_SOCKOP_SO_BROADCAST        (1 << 2)
+#define STREAM_SOCKOP_IPV6_V6ONLY         (1 << 3)
+#define STREAM_SOCKOP_IPV6_V6ONLY_ENABLED (1 << 4)
+
+
 /* uncomment this to debug poll(2) emulation on systems that have poll(2) */
 /* #define PHP_USE_POLL_2_EMULATION 1 */
 
-#if defined(HAVE_SYS_POLL_H) && defined(HAVE_POLL)
-# include <sys/poll.h>
+#if defined(HAVE_POLL)
+# if defined(HAVE_POLL_H)
+#  include <poll.h>
+# elif defined(HAVE_SYS_POLL_H)
+#  include <sys/poll.h>
+# endif
 typedef struct pollfd php_pollfd;
 #else
 typedef struct _php_pollfd {
@@ -224,49 +240,49 @@ typedef struct {
 #endif
 
 BEGIN_EXTERN_C()
-PHPAPI int php_network_getaddresses(const char *host, int socktype, struct sockaddr ***sal, char **error_string TSRMLS_DC);
+PHPAPI int php_network_getaddresses(const char *host, int socktype, struct sockaddr ***sal, zend_string **error_string);
 PHPAPI void php_network_freeaddresses(struct sockaddr **sal);
 
 PHPAPI php_socket_t php_network_connect_socket_to_host(const char *host, unsigned short port,
-		int socktype, int asynchronous, struct timeval *timeout, char **error_string,
-		int *error_code, char *bindto, unsigned short bindport 
-		TSRMLS_DC);
+		int socktype, int asynchronous, struct timeval *timeout, zend_string **error_string,
+		int *error_code, char *bindto, unsigned short bindport, long sockopts
+		);
 
 PHPAPI int php_network_connect_socket(php_socket_t sockfd,
 		const struct sockaddr *addr,
 		socklen_t addrlen,
 		int asynchronous,
 		struct timeval *timeout,
-		char **error_string,
+		zend_string **error_string,
 		int *error_code);
 
 #define php_connect_nonb(sock, addr, addrlen, timeout) \
 	php_network_connect_socket((sock), (addr), (addrlen), 0, (timeout), NULL, NULL)
 
 PHPAPI php_socket_t php_network_bind_socket_to_local_addr(const char *host, unsigned port,
-		int socktype, char **error_string, int *error_code
-		TSRMLS_DC);
+		int socktype, long sockopts, zend_string **error_string, int *error_code
+		);
 
 PHPAPI php_socket_t php_network_accept_incoming(php_socket_t srvsock,
-		char **textaddr, long *textaddrlen,
+		zend_string **textaddr,
 		struct sockaddr **addr,
 		socklen_t *addrlen,
 		struct timeval *timeout,
-		char **error_string,
+		zend_string **error_string,
 		int *error_code
-		TSRMLS_DC);
+		);
 
-PHPAPI int php_network_get_sock_name(php_socket_t sock, 
-		char **textaddr, long *textaddrlen,
+PHPAPI int php_network_get_sock_name(php_socket_t sock,
+		zend_string **textaddr,
 		struct sockaddr **addr,
 		socklen_t *addrlen
-		TSRMLS_DC);
-	
-PHPAPI int php_network_get_peer_name(php_socket_t sock, 
-		char **textaddr, long *textaddrlen,
+		);
+
+PHPAPI int php_network_get_peer_name(php_socket_t sock,
+		zend_string **textaddr,
 		struct sockaddr **addr,
 		socklen_t *addrlen
-		TSRMLS_DC);
+		);
 
 PHPAPI void php_any_addr(int family, php_sockaddr_storage *addr, unsigned short port);
 PHPAPI int php_sockaddr_size(php_sockaddr_storage *addr);
@@ -285,31 +301,35 @@ extern php_stream_ops php_stream_generic_socket_ops;
 #define PHP_STREAM_IS_SOCKET	(&php_stream_socket_ops)
 
 BEGIN_EXTERN_C()
-PHPAPI php_stream *_php_stream_sock_open_from_socket(php_socket_t socket, const char *persistent_id STREAMS_DC TSRMLS_DC );
+PHPAPI php_stream *_php_stream_sock_open_from_socket(php_socket_t socket, const char *persistent_id STREAMS_DC );
 /* open a connection to a host using php_hostconnect and return a stream */
 PHPAPI php_stream *_php_stream_sock_open_host(const char *host, unsigned short port,
-		int socktype, struct timeval *timeout, const char *persistent_id STREAMS_DC TSRMLS_DC);
+		int socktype, struct timeval *timeout, const char *persistent_id STREAMS_DC);
 PHPAPI void php_network_populate_name_from_sockaddr(
 		/* input address */
 		struct sockaddr *sa, socklen_t sl,
 		/* output readable address */
-		char **textaddr, long *textaddrlen,
+		zend_string **textaddr,
 		/* output address */
 		struct sockaddr **addr,
 		socklen_t *addrlen
-		TSRMLS_DC);
+		);
 
 PHPAPI int php_network_parse_network_address_with_port(const char *addr,
-		long addrlen, struct sockaddr *sa, socklen_t *sl TSRMLS_DC);
+		zend_long addrlen, struct sockaddr *sa, socklen_t *sl);
+
+PHPAPI struct hostent*	php_network_gethostbyname(char *name);
+
+PHPAPI int php_set_sock_blocking(php_socket_t socketd, int block);
 END_EXTERN_C()
 
-#define php_stream_sock_open_from_socket(socket, persistent)	_php_stream_sock_open_from_socket((socket), (persistent) STREAMS_CC TSRMLS_CC)
-#define php_stream_sock_open_host(host, port, socktype, timeout, persistent)	_php_stream_sock_open_host((host), (port), (socktype), (timeout), (persistent) STREAMS_CC TSRMLS_CC)
+#define php_stream_sock_open_from_socket(socket, persistent)	_php_stream_sock_open_from_socket((socket), (persistent) STREAMS_CC)
+#define php_stream_sock_open_host(host, port, socktype, timeout, persistent)	_php_stream_sock_open_host((host), (port), (socktype), (timeout), (persistent) STREAMS_CC)
 
 /* {{{ memory debug */
-#define php_stream_sock_open_from_socket_rel(socket, persistent)	_php_stream_sock_open_from_socket((socket), (persistent) STREAMS_REL_CC TSRMLS_CC)
-#define php_stream_sock_open_host_rel(host, port, socktype, timeout, persistent)	_php_stream_sock_open_host((host), (port), (socktype), (timeout), (persistent) STREAMS_REL_CC TSRMLS_CC)
-#define php_stream_sock_open_unix_rel(path, pathlen, persistent, timeval)	_php_stream_sock_open_unix((path), (pathlen), (persistent), (timeval) STREAMS_REL_CC TSRMLS_CC)
+#define php_stream_sock_open_from_socket_rel(socket, persistent)	_php_stream_sock_open_from_socket((socket), (persistent) STREAMS_REL_CC)
+#define php_stream_sock_open_host_rel(host, port, socktype, timeout, persistent)	_php_stream_sock_open_host((host), (port), (socktype), (timeout), (persistent) STREAMS_REL_CC)
+#define php_stream_sock_open_unix_rel(path, pathlen, persistent, timeval)	_php_stream_sock_open_unix((path), (pathlen), (persistent), (timeval) STREAMS_REL_CC)
 
 /* }}} */
 
